nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Tempsense1Clr

Struct Tempsense1Clr 

#[repr(transparent)]
pub struct Tempsense1Clr(pub u32);
Tempsensor Control Register 1

Tuple Fields

0: u32

Implementations

Source

impl Tempsense1Clr

pub const fn measure_freq(&self) -> u16

This bits determines how many RTC clocks to wait before automatically repeating a temperature measurement

pub const fn set_measure_freq(&mut self, val: u16)

This bits determines how many RTC clocks to wait before automatically repeating a temperature measurement